Test CSS Locators
open | ../tests/html/test_locators.html |
verifyElementPresent | css=* |
verifyText | css=p | this is the first element in the document
verifyText | css=a | this is the first element
verifyText | css=a#id3 | this is the third element
verifyElementPresent | css=input[name] |
verifyText | css=a[href="#id3"] | this is the third element
verifyElementNotPresent | css=span[selenium:foo] |
verifyText | css=a[class~="class2"] | this is the fifth element
verifyText | css=a[lang|="en"] | this is the sixth element
verifyElementPresent | css=a.a1 | this is the first element
verifyText | css=th:first-child | theHeaderText
verifyText | css=a:lang(en) | this is the first element
verifyText | css=#linkPseudoTest :link | link pseudo test
verifyText | css=div#combinatorTest a | and grandson
verifyText | css=div#combinatorTest > span | this is a child and grandson
verifyText | css=span#firstChild + span | another child
verifyText | css=a[name^="foo"] | foobar
verifyText | css=a[name$="foo"] | barfoo
verifyText | css=a[name*="zoo"] | foozoobar
verifyText | css=a[name*="name"][alt] | this is the second element
verifyElementPresent | css=html:root |
verifyText | css=div#structuralPseudo :nth-child(2n) | span2
verifyText | css=div#structuralPseudo :nth-child(2) | span2
verifyText | css=div#structuralPseudo :nth-child(-n+6) | span1
verifyText | css=div#structuralPseudo :nth-last-child(4n+1) | span4
verifyText | css=div#structuralPseudo :nth-last-child(2) | div3
verifyText | css=div#structuralPseudo :nth-last-child(-n+6) | span3
verifyText | css=div#structuralPseudo :first-child | span1
verifyText | css=div#structuralPseudo :last-child | div4
verifyText | css=div#onlyChild span:only-child | only child
verifyElementPresent | css=span:empty |
verifyText | css=div#targetTest span:target | target
verifyElementPresent | css=input[type="text"]:enabled |
verifyElementPresent | css=input[type="text"]:disabled |
verifyElementPresent | css=input[type="checkbox"]:checked |
verifyText | css=a:contains("zoo") | foozoobar
verifyText | css=div#structuralPseudo span:not(:first-child) | span2
verifyText | css=div#structuralPseudo :not(span):not(:last-child) | div1
verifyText | css=div#combinatorTest span#firstChild ~ span | another child